# Scanning Processes

For the YARA scanner to operate correctly, the rules have to be compiled and loaded into the engine. This is accomplished by providing file system paths with YARA rule definitions in the `rule.paths` configuration keys. The directories are scanned recursively for any `.yar` file. Alternatively, it is possible to provide the rules as inline strings directly in the Fibratus configuration file.

In addition to process scanning, Fibratus also performs file scanning for modules mapped into the process address space. You can control whether file scanning is enabled by changing the `skip-files` option.

### Configuration {docsify-ignore}

YARA scanner related options are located in the `yara` section of the configuration file.

#### enabled

Indicates if the YARA scanner is enabled. When enabled, each newly created process is scanned for pattern matches.

**default**: `false`

#### rule

The `rule` key contains various nested keys. The `paths` key identifies directories that hold the YARA rule definitions. It is also possible to link each directory to YARA namespace. The `strings` key allows for defining inline YARA rules. Example:

```
rule:
  paths:
    - path: C:\\yara-rules
      namespace: default
    - path: C:\\pdf-rules
      namespace: pdf

  strings:
    - string: rule test : tag1 { meta: author = \"Hilko Bengen\" strings: $a = \"abc\" fullword condition: $a }
      namespace: notepad
```

#### alert-via

Indicates which sender is used to transport the alert generated by YARA scanner.

**default**: `mail`

#### alert-template:

Specifies templates for the alert title and text in Go [templating](https://golang.org/pkg/text/template) language. You can specify a distinct template for both the `title` and the `text`.

Default `title` template:

```
{{if .PS }}YARA alert on process {{ .PS.Name }}{{ else }}YARA alert on file {{ .Filename }}{{ end }}
```

Default `text` template:

```
{{ if .PS }}
	Possible malicious process, {{ .PS.Name }} ({{ .PS.PID }}), detected at {{ .Timestamp }}.

	Rule matches
	{{- with .Matches }}
	{{ range . }}
		Rule: {{ .Rule }}
		Namespace: {{ .Namespace }}
		Meta: {{ .Meta }}
		Tags: {{ .Tags }}
	{{ end }}
	{{- end }}

	Process information

	Name: 		{{ .PS.Name }}
	PID:  		{{ .PS.PID }}
	PPID: 		{{ .PS.Ppid }}
	Comm:		{{ .PS.Comm }}
	Cwd:		{{ .PS.Cwd }}
	SID:		{{ .PS.SID }}
	Session ID: {{ .PS.SessionID }}
	{{ if .PS.Envs }}
	Env:
			{{- with .PS.Envs }}
			{{- range $k, $v := . }}
			{{ $k }}: {{ $v }}
			{{- end }}
			{{- end }}
	{{ end }}
	Threads:
			{{- with .PS.Threads }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	Modules:
			{{- with .PS.Modules }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	{{ if .PS.Handles }}
	Handles:    
			{{- with .PS.Handles }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	{{ end }}

	{{ if .PS.PE }}
	Entrypoint:  		{{ .PS.PE.EntryPoint }}
	Image base: 		{{ .PS.PE.ImageBase }}
	Build date:  		{{ .PS.PE.LinkTime }}

	Number of symbols: 	{{ .PS.PE.NumberOfSymbols }}
	Number of sections: {{ .PS.PE.NumberOfSections }}

	Sections:
			{{- with .PS.PE.Sections }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	{{ if .PS.PE.Symbols }}
	Symbols:
			{{- with .PS.PE.Symbols }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	{{ end }}
	{{ if .PS.PE.Imports }}
	Imports:
			{{- with .PS.PE.Imports }}
			{{- range . }}
			{{ . }}
			{{- end }}
			{{- end }}
	{{ end }}
	{{ if .PS.PE.VersionResources }}
	Resources:
			{{- with .PS.PE.VersionResources }}
			{{- range $k, $v := . }}
			{{ $k }}: {{ $v }}
			{{- end }}
			{{- end }}
	{{ end }}
	{{ end }}

	{{ else }}

	Possible malicious file, {{ .Filename }}, detected at {{ .Timestamp }}.

	Rule matches
	{{ with .Matches }}
	{{ range . }}
		Rule: {{ .Rule }}
		Namespace: {{ .Namespace }}
		Meta: {{ .Meta }}
		Tags: {{ .Tags }}
	{{ end }}
	{{ end }}

	{{ end }}
```

#### fastscan

Determines when multiple matches of the same string can be avoided when not necessary.

**default**: `true`

#### scan-timeout

Specifies the timeout for the scanner. If the timeout is reached, the scan operation is cancelled.

**default**: `20s`

#### skip-files

Indicates whether file scanning is enabled. This affects scans triggered by the image loading events.

**default**: `false`

#### excluded-files

Contains the list of file names that shouldn't be scanned.

#### excluded-procs

Contains the list of process image names that shouldn't be scanned.
